==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/win/WSwincom.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team 
// shall not be used in advertising or otherwise to promote the sale, use or 
// other dealings in this Software without prior written authorization from  
// WideStudio Development Team.


#ifndef WSWINCOM_H
#define WSWINCOM_H

#include <windows.h>
#include <WScom.h>
#define WS_JOIN JoinMiter
#define UNSPECIFIED_PIXMAP 2
struct WinEvent{
UINT message;
WPARAM uParam;
LPARAM lParam;
};

#ifdef _WSWINCE
extern int SetDIBits(HDC,HBITMAP,UINT,UINT,void*,BITMAPINFO*,UINT);
extern int GetDIBits(HDC,HBITMAP,UINT,UINT,void*,BITMAPINFO*,UINT);
extern int GdiFlush();
#endif

#if 0
extern void WSGFwinDrawTextString(HDC dc,HFONT font,
                                 COLORREF fg,COLORREF bg,
                                 short x,short y,char* str,
                                 short cur_pos,WSCbool inter_cur,
                                 WSCushort linew);
extern Pixmap WSGFxGetPixmap(WSCushort w,WSCushort h);
extern void   WSGFxReleasePixmap(Pixmap);
#endif
#endif //WSWINCOM_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/win/WSwincom.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.


#ifndef WSWINCOM_H
#define WSWINCOM_H

#include <windows.h>
#include <WScom.h>

#define WS_WIN_LOCK 4
#define WS_WIN_ALLOW_EXEC_EVT 5
#define WM_UNLOCK (WM_USER+0x2000)
#define WM_CREATE_NEW_WINDOW (WM_USER+0x2001)
#define WM_CREATE_NEW_WINDOW_EX (WM_USER+0x2002)
#define WM_DESTROY_WINDOW (WM_USER+0x2003)


#define WS_JOIN JoinMiter
#define UNSPECIFIED_PIXMAP 2
struct WinEvent{
UINT message;
WPARAM uParam;
LPARAM lParam;
HWND hWnd;
};

#ifdef _WSWINCE
extern int SetDIBits(HDC,HBITMAP,UINT,UINT,void*,BITMAPINFO*,UINT);
extern int GetDIBits(HDC,HBITMAP,UINT,UINT,void*,BITMAPINFO*,UINT);
extern int GdiFlush();
#endif

#if 0
extern void WSGFwinDrawTextString(HDC dc,HFONT font,
                                 COLORREF fg,COLORREF bg,
                                 short x,short y,char* str,
                                 short cur_pos,WSCbool inter_cur,
                                 WSCushort linew);
extern Pixmap WSGFxGetPixmap(WSCushort w,WSCushort h);
extern void   WSGFxReleasePixmap(Pixmap);
#endif

extern HWND WSGFcreateWindow(char*,char*,DWORD,int,int,int,int,HWND,
                               HMENU,HINSTANCE,void*);
extern HWND WSGFcreateWindowEx(DWORD,char*,char*,DWORD,int,int,int,int,HWND,
                               HMENU,HINSTANCE,void*);
extern void WSGFreplyCreateWindowRequest(void* pt);
extern void WSGFreplyCreateWindowRequestEx(void* pt);

extern BOOL WSGFdestroyWindow(HWND);
extern void WSGFreplyDestroyWindowRequest(HWND);

#endif //WSWINCOM_H
